@@ -17,20 +17,20 @@ def distance(a: Coordinate, b: Coordinate) -> float:
     """Calculates the distance between two coordinates.
 
     Args:
-        a (Coordinate2D): First coordinate.
-        b (Coordinate2D): Second coordinate.
+        a (Coordinate): First coordinate.
+        b (Coordinate): Second coordinate.
 
     Raises:
-        TypeError: If a or b are not Coordinate2D objects.
+        TypeError: If a or b are not Coordinate objects.
 
     Returns:
         float: Distance between the two coordinates.
     """
 
     if not isinstance(a, Coordinate):
-        raise TypeError("a must be a Coordinate2D instance")
+        raise TypeError("a must be a Coordinate instance")
     elif not isinstance(b, Coordinate):
-        raise TypeError("b must be a Coordinate2D instance")
+        raise TypeError("b must be a Coordinate instance")
 
     return math.sqrt((a.x - b.x) ** 2 + (a.y - b.y) ** 2)
 
@@ -39,23 +39,23 @@ def angle(a: Coordinate, b: Coordinate, c: Coordinate) -> float:
     """Calculates the angle between three coordinates.
 
     Args:
-        a (Coordinate2D): First coordinate.
-        b (Coordinate2D): Second coordinate.
-        c (Coordinate2D): Third coordinate.
+        a (Coordinate): First coordinate.
+        b (Coordinate): Second coordinate.
+        c (Coordinate): Third coordinate.
 
     Raises:
-        TypeError: If a, b or c are not Coordinate2D objects.
+        TypeError: If a, b or c are not Coordinate objects.
 
     Returns:
         float: Angle between the three coordinates.
     """
 
     if not isinstance(a, Coordinate):
-        raise TypeError("a must be a Coordinate2D instance")
+        raise TypeError("a must be a Coordinate instance")
     elif not isinstance(b, Coordinate):
-        raise TypeError("b must be a Coordinate2D instance")
+        raise TypeError("b must be a Coordinate instance")
     elif not isinstance(c, Coordinate):
-        raise TypeError("c must be a Coordinate2D instance")
+        raise TypeError("c must be a Coordinate instance")
 
     e1 = distance(b, c)
     e2 = distance(a, c)
@@ -70,19 +70,19 @@ def midpoint(a: Coordinate, b: Coordinate) -> Coordinate:
     """Calculates the midpoint between two coordinates.
 
     Args:
-        a (Coordinate2D): First coordinate.
-        b (Coordinate2D): Second coordinate.
+        a (Coordinate): First coordinate.
+        b (Coordinate): Second coordinate.
 
     Raises:
-        TypeError: If a or b are not Coordinate2D objects.
+        TypeError: If a or b are not Coordinate objects.
 
     Returns:
-        Coordinate2D: Midpoint between the two coordinates.
+        Coordinate: Midpoint between the two coordinates.
     """
 
     if not isinstance(a, Coordinate):
-        raise TypeError("a must be a Coordinate2D instance")
+        raise TypeError("a must be a Coordinate instance")
     elif not isinstance(b, Coordinate):
-        raise TypeError("b must be a Coordinate2D instance")
+        raise TypeError("b must be a Coordinate instance")
 
     return Coordinate((a.x + b.x) / 2, (a.y + b.y) / 2)
